@@ -69,6 +69,11 @@ class Delta:
         serializer=pickle_dump,
         verify_symmetry=False,
     ):
+        if 'safe_to_import' not in set(deserializer.__code__.co_varnames):
+            def _deserializer(obj, safe_to_import=None):
+                return deserializer(obj)
+        else:
+            _deserializer = deserializer
 
         if diff is not None:
             if isinstance(diff, DeepDiff):
@@ -76,17 +81,17 @@ class Delta:
             elif isinstance(diff, Mapping):
                 self.diff = diff
             elif isinstance(diff, strings):
-                self.diff = deserializer(diff, safe_to_import=safe_to_import)
+                self.diff = _deserializer(diff, safe_to_import=safe_to_import)
         elif delta_path:
             with open(delta_path, 'rb') as the_file:
                 content = the_file.read()
-            self.diff = deserializer(content, safe_to_import=safe_to_import)
+            self.diff = _deserializer(content, safe_to_import=safe_to_import)
         elif delta_file:
             try:
                 content = delta_file.read()
             except UnicodeDecodeError as e:
                 raise ValueError(BINIARY_MODE_NEEDED_MSG.format(e)) from None
-            self.diff = deserializer(content, safe_to_import=safe_to_import)
+            self.diff = _deserializer(content, safe_to_import=safe_to_import)
         else:
             raise ValueError(DELTA_AT_LEAST_ONE_ARG_NEEDED)
 
@@ -262,16 +267,23 @@ class Delta:
     def _do_dictionary_item_added(self):
         dictionary_item_added = self.diff.get('dictionary_item_added')
         if dictionary_item_added:
-            self._do_item_added(dictionary_item_added)
+            self._do_item_added(dictionary_item_added, sort=False)
 
     def _do_attribute_added(self):
         attribute_added = self.diff.get('attribute_added')
         if attribute_added:
             self._do_item_added(attribute_added)
 
-    def _do_item_added(self, items):
-        # sorting the items by their path so that the items with smaller index are applied first.
-        for path, new_value in sorted(items.items(), key=lambda x: x[0]):
+    def _do_item_added(self, items, sort=True):
+        if sort:
+            # sorting items by their path so that the items with smaller index
+            # are applied first (unless `sort` is `False` so that order of
+            # added items is retained, e.g. for dicts).
+            items = sorted(items.items(), key=lambda x: x[0])
+        else:
+            items = items.items()
+
+        for path, new_value in items:
             elem_and_details = self._get_elements_and_details(path)
             if elem_and_details:
                 elements, parent, parent_to_obj_elem, parent_to_obj_action, obj, elem, action = elem_and_details
@@ -512,7 +524,16 @@ class Delta:
         """
         Dump into file object
         """
-        file.write(self.dumps())
+        # Small optimization: Our internal pickle serializer can just take a file object
+        # and directly write to it. However if a user defined serializer is passed
+        # we want to make it compatible with the expectation that self.serializer(self.diff)
+        # will give the user the serialization and then it can be written to
+        # a file object when using the dump(file) function.
+        param_names_of_serializer = set(self.serializer.__code__.co_varnames)
+        if 'file_obj' in param_names_of_serializer:
+            self.serializer(self.diff, file_obj=file)
+        else:
+            file.write(self.dumps())
 
     def dumps(self):
         """
